# GitBook Downloader
![NPM Version](https://img.shields.io/npm/v/gitbook-downloader.svg?label=package&style=flat-square)
![NPM VERSION](https://img.shields.io/npm/v/gitbook-dl.svg?label=cli&style=flat-square)

Download GitBook documentation as markdown files. Supports both CLI usage and programmatic integration.

inspired by [gitbook-downloader (python)](https://github.com/Amal-David/gitbook-downloader)
## CLI Usage

You can use the CLI tool without installation via `npx`:

```bash
npx gitbook-dl <gitbook-url> -o output.md
```

Or install it globally:

```bash
# Using pnpm (recommended)
pnpm add -g gitbook-dl

# Using npm
npm install -g gitbook-dl

# Using yarn
yarn global add gitbook-dl
```

### CLI Options

```bash
gitbook-dl --help

Options:
  -V, --version           output the version number
  -o, --output <file>     output file path (default: "output.md")
  -d, --delay <ms>        delay between requests in milliseconds (default: "1000")
  -r, --retries <number>  maximum number of retries (default: "3")
  -h, --help             display help for command
```

## Library Usage

You can also use GitBook Downloader as a library in your TypeScript/JavaScript projects:

```bash
# Using pnpm (recommended)
pnpm add gitbook-downloader

# Using npm
npm install gitbook-downloader

# Using yarn
yarn add gitbook-downloader
```

### Example Usage

```typescript
import { GitbookDownloader } from 'gitbook-downloader';

async function downloadDocs() {
  // Basic usage
  const downloader = new GitbookDownloader('https://your-gitbook-url.com');
  const markdown = await downloader.download();
  
  // With options
  const downloaderWithOptions = new GitbookDownloader('https://your-gitbook-url.com', {
    delay: 1000,        // Delay between requests in milliseconds
    maxRetries: 3,      // Maximum number of retries for failed requests
    outputPath: 'docs.md' // Output file path
  });
  
  const markdownWithOptions = await downloaderWithOptions.download();
}
```

## Features

- Download complete GitBook documentation as markdown
- Configurable request delays to prevent rate limiting
- Automatic retry on failed requests
- Progress logging
- TypeScript support
- Both CLI and programmatic usage

upcoming features:
- clean md files from --, `Last updated` and `images`

## License

MIT License - see LICENSE file for details