/**
 * Fetch a page with a preliminary ping and delay.
 *
 * This function first pings the server with a HEAD request to potentially warm up
 * any caches or trigger server-side processes, waits for a specified delay,
 * and then fetches the full HTML content.
 *
 * @param url - The URL of the page to fetch.
 * @param pingDelayMs - The delay in milliseconds to wait after pinging the server.
 * @param fetchDelayMs - Optional additional delay in milliseconds after fetching the page.
 * @returns The raw HTML text of the page.
 * @throws An error if the ping or fetch fails.
 */
export declare function fetchPageWithDelay(url: string, options: {
    pingDelayMs: number;
    fetchDelayMs: number;
}): Promise<string>;
export declare class RateLimitError extends Error {
    resetTime: Date;
    constructor(message: string, resetTime: Date);
}
